#include "passwdos.h"

/*****************************************************************************
 * passwdos-p
 *
 *   This is the passwdos's "password printer" process.
 *   It prints the password, one character at a time, into the "pipe
 *   buffer", which is just the byte of memory at location PIPEBUF.
 *
 *   After printing a character, it waits for the passwdos-c program to read
 *   that character before continuing.
 *   It can tell because passwdos-c clears the buffer, setting it to 0,
 *   after reading the character.
 *
 *   Once passwdos-p has printed its whole password, it just loops forever,
 *   handing control back to passwdos-c.
 *
 *   The _yield function passes control FROM one process TO another.
 *   The FROM process ID is the first argument; here, since we are in
 *   passwdos-p, that argument is PROCESSID_P.
 *   The TO process ID is the second argument; here, since we want to
 *   pass control to passwdos-c, that argument is PROCESSID_C.
 *   _yield is defined in passwdos-yield.S.
 *
 *****************************************************************************/

void
putch(char c)
{
	*PIPEBUF = c;

	while (*PIPEBUF != 0)
		_yield(PROCESSID_P, PROCESSID_C);
}

void
start(void)
{
	putch('1');
	putch('1');
	putch('1');
	putch('\n');

	while (1)
		_yield(PROCESSID_P, PROCESSID_C);
}
